%define         srcname       gdl

#ImageMagick caused issues with plplot < 5.9.0
%define         with_magick   ON

#works now
%define         with_hdf4     ON

#not compulsory, but certainly faster
%define         with_fftw     ON

#compilation is buggy and PYTHON.txt claims that "Due to the
#neglectible feedback, the python module development is currently on
#hold"
%define         with_pymodule OFF

#but we still want to call python from GDL
#currently broken
%define         with_python   ON

#we would need to import eccodes, I've tried. This package is full of
#bugs, full of packaging shits, and upstream does not seem to care
%define         with_grib     OFF

%define         prodir        gnudatalanguage

#define         gitcommit

%define         rel           1

Name:           gnudl
Version:        1.0.2
#Release:        #mkrel -c #{gitcommit} #{rel}
Release:         %mkrel %{rel}
Summary:        A free incremental compiler quite similar and compatible with IDL
License:        GPLv2+
Group:          Sciences/Physics

URL:            https://github.com/gnudatalanguage/gdl
Source0:        https://sourceforge.net/projects/gnudatalanguage/files/gdl/%{version}/%{srcname}-%{version}.tar.gz
Patch0:         gdl-mga-fix-building-with-libtiff-4.5.patch

BuildRequires:  sed
BuildRequires:  grep
BuildRequires:  gcc-c++
BuildRequires:  cmake
BuildRequires:  glpk
BuildRequires:  pkgconfig(pkg-config)
BuildRequires:  libstdc++-devel
BuildRequires:  libgomp-devel
BuildRequires:  readline-devel
BuildRequires:  wxgtk-devel
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(plplot) >= 5.9.10-1
BuildRequires:  pkgconfig(netcdf)
BuildRequires:  netcdf-cxx4-devel
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  hdf5-devel
BuildRequires:  hdf-devel
BuildRequires:  openmpi-devel
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  libudunits2-devel
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libps)
BuildRequires:  pkgconfig(ImageMagick)
BuildRequires:  pkgconfig(GraphicsMagick)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  udunits2-devel
BuildRequires:  qhull-devel
BuildRequires:  pkgconfig(geotiff)
BuildRequires:  pkgconfig(ompi)
BuildRequires:  glpk-devel
BuildRequires:  pkgconfig(libtirpc)

#contains required font files
Requires:       plplot
#needs mpi daemon to run
Requires:       openmpi

%description
A free compatible incremental compiler (i.e. runs Interactive Data
Language programs). IDL is a registered trademark of ITT Visual
Information Solutions. All IDL language elements up to IDL version 7.1
are supported and more than 380 library routines are implemented. For
a sorted list enter HELP,/LIB at the command prompt and look for
library routines written in GDL in the %prodir/lib directory.


%prep
%autosetup -p1 -n %{srcname}-%{version}

# fix build with new proj
sed -i -e 's/proj_api.h/proj.h/g' src/projections.hpp

%build
#duplicate symbols on arm 32 bits only
#https://github.com/gnudatalanguage/gdl/issues/677
%ifarch %arm
%global build_ldflags %build_ldflags -z muldefs
export CXXFLAGS="%{optflags} -std=c++17"
export LDFLAGS="%{ldflags} -Wl,--allow-multiple-definition"
%endif
%cmake           -Wno-dev \
                 -DMAGICK:BOOL=%{with_magick} \
                 -DHDF:BOOL=%{with_hdf4} \
                 -DFFTW:BOOL=%{with_fftw} \
                 -DPYTHON:BOOL=%{with_python} \
                 -DPYTHONVERSION=3            \
                 -DPYTHON_EXECUTABLE=%{__python3}      \
                 -DPYTHON_MODULE:BOOL=%{with_pymodule} \
                 -DWXWIDGETS:BOOL=ON \
                 -DUDUNITS:BOOL=ON \
                 -DUDUNITSDIR=%{_includedir}/udunits2 \
                 -DGRAPHICSMAGICK:BOOL=ON \
                 -DLIBPROJ4:BOOL=ON \
                 -DOPENMP:BOOL=ON \
		 -DMPI:BOOL=ON \
		 -DGRIB:BOOL=%{with_grib}

%cmake_build


%install
%cmake_install


%files
%doc README README.md AUTHORS NEWS HACKING MAP_INSTALL
%license COPYING 
%{_mandir}/man1/*
%{_bindir}/gdl
%{_datadir}/%prodir


%changelog
* Fri Jan 20 2023 eatdirt <eatdirt> 1.0.2-1.mga9
+ Revision: 1934490
- Update to version 1.0.2

* Thu Dec 29 2022 daviddavid <daviddavid> 1.0.1-11.mga9
+ Revision: 1927506
- rebuild for new gsl 2.7.1

* Tue Dec 13 2022 ns80 <ns80> 1.0.1-10.mga9
+ Revision: 1921620
- add a patch to fix building with libtiff 4.5
- rebuild for new libtiff

* Mon Dec 05 2022 eatdirt <eatdirt> 1.0.1-9.mga9
+ Revision: 1918300
- Rebuild for new hdf5

* Fri Jul 15 2022 wally <wally> 1.0.1-8.mga9
+ Revision: 1868970
- rebuild for wxgtk 3.2.0

* Mon Jun 13 2022 wally <wally> 1.0.1-7.mga9
+ Revision: 1864367
- rebuild for wxgtk 3.1.7
+ eatdirt <eatdirt>
- Rebuild for new proj

* Thu Apr 14 2022 wally <wally> 1.0.1-6.mga9
+ Revision: 1849893
- rebuild for wxgtk 3.1.6
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Feb 17 2022 tv <tv> 1.0.1-4.mga9
+ Revision: 1778418
- Rebuild for python-3.10

* Sat Jan 15 2022 wally <wally> 1.0.1-3.mga9
+ Revision: 1768476
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Sat Jan 01 2022 wally <wally> 1.0.1-2.mga9
+ Revision: 1765706
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Sat Dec 11 2021 eatdirt <eatdirt> 1.0.1-1.mga9
+ Revision: 1761445
- Upgrade to version 1.0.1

* Wed Aug 25 2021 eatdirt <eatdirt> 1.0.0-3.mga9
+ Revision: 1742559
- Add missing Requires to openmpi

* Wed Aug 25 2021 eatdirt <eatdirt> 1.0.0-2.mga9
+ Revision: 1742538
- Build against wxgtk-3.1 instead of 3.0

* Tue Aug 24 2021 eatdirt <eatdirt> 1.0.0-1.mga9
+ Revision: 1742527
- Upgrade to stable version 1.0.0

* Fri Mar 26 2021 daviddavid <daviddavid> 1.0.0-0.rc.3.12.mga9
+ Revision: 1710325
- rebuild for python 3.9

* Sun Jan 03 2021 wally <wally> 1.0.0-0.rc.3.11.mga8
+ Revision: 1668489
- BR libtirpc

* Mon Oct 26 2020 akien <akien> 1.0.0-0.rc.3.10.mga8
+ Revision: 1639572
- Rebuild against libnetcdf18
+ eatdirt <eatdirt>
- Rebuild for new netcdf

* Fri Oct 02 2020 tv <tv> 1.0.0-0.rc.3.8.mga8
+ Revision: 1631663
- build with '-z muldefs' on arm

* Tue Sep 29 2020 tv <tv> 1.0.0-0.rc.3.7.mga8
+ Revision: 1631213
- use %%license

* Sat Sep 05 2020 eatdirt <eatdirt> 1.0.0-0.rc.3.6.mga8
+ Revision: 1622508
- Rebuild for new libwx
+ wally <wally>
- rebuild for new wxgtk 3.1.4

* Sat Jul 11 2020 eatdirt <eatdirt> 1.0.0-0.rc.3.4.mga8
+ Revision: 1605289
- Tentative fix for arm with std=c++17

* Sat Jul 11 2020 eatdirt <eatdirt> 1.0.0-0.rc.3.3.mga8
+ Revision: 1605279
- Tentative fix for arm

* Sat Jul 11 2020 eatdirt <eatdirt> 1.0.0-0.rc.3.2.mga8
+ Revision: 1605273
- Rebuild for armv7hl

* Sat Jul 11 2020 eatdirt <eatdirt> 1.0.0-0.rc.3.1.mga8
+ Revision: 1605230
- Upgrade to version 1.0.0-rc.3
+ danf <danf>
- Switch URLs from http: to https:

* Fri Mar 20 2020 eatdirt <eatdirt> 1.0.0-0.rc.2.3.mga8
+ Revision: 1558237
- Rebuild for new libproj

* Wed Mar 18 2020 eatdirt <eatdirt> 1.0.0-0.rc.2.2.mga8
+ Revision: 1557656
- Switch on python and MPI support

* Tue Mar 17 2020 eatdirt <eatdirt> 1.0.0-0.rc.2.1.mga8
+ Revision: 1557592
- Upgrade to version 1.0.0-rc.2

* Thu Feb 20 2020 umeabot <umeabot> 0.9.10-0.git17f1fb1.5.mga8
+ Revision: 1545442
- Mageia 8 Mass Rebuild

* Wed Jan 29 2020 daviddavid <daviddavid> 0.9.10-0.git17f1fb1.4.mga8
+ Revision: 1484776
- rebuild for new plplot 5.15.0

* Sat Jan 04 2020 luigiwalser <luigiwalser> 0.9.10-0.git17f1fb1.3.mga8
+ Revision: 1475955
- rebuild for readline
+ wally <wally>
- build with new cmake macros

* Tue Nov 12 2019 wally <wally> 0.9.10-0.git17f1fb1.2.mga8
+ Revision: 1459465
- rebuild for wxgtk 3.1.3

* Fri Aug 30 2019 eatdirt <eatdirt> 0.9.10-0.git17f1fb1.1.mga8
+ Revision: 1435623
- Upgrade to latest git version, temporarily disabling buggy python3 support
- Fix abort at startup (bad GraphicsMagick initialization)

* Tue Aug 27 2019 daviddavid <daviddavid> 0.9.9-8.mga8
+ Revision: 1433754
- rebuild for new gsl 2.6

* Sat Jul 20 2019 wally <wally> 0.9.9-7.mga8
+ Revision: 1423106
- rebuild with gtk3 enabled wxgtk 3.1.2
- update URL

* Wed Apr 17 2019 daviddavid <daviddavid> 0.9.9-6.mga7
+ Revision: 1391857
- rebuild for new geotiff 1.5.1

* Fri Mar 08 2019 eatdirt <eatdirt> 0.9.9-5.mga7
+ Revision: 1372897
- Fix missing optflags

* Fri Mar 08 2019 eatdirt <eatdirt> 0.9.9-4.mga7
+ Revision: 1372888
- Fix build against libproj 6.0
- Rebuild for new libproj

* Mon Mar 04 2019 eatdirt <eatdirt> 0.9.9-2.mga7
+ Revision: 1371494
- Rebuild for new plplot

* Fri Dec 14 2018 eatdirt <eatdirt> 0.9.9-1.mga7
+ Revision: 1341210
- Upgrade to version 0.9.9

* Thu Nov 08 2018 daviddavid <daviddavid> 0.9.8-4.mga7
+ Revision: 1328927
- rebuild for new hdf5 1.10.4

* Fri Oct 05 2018 umeabot <umeabot> 0.9.8-3.mga7
+ Revision: 1317777
- Mageia 7 Mass Rebuild

* Mon Aug 13 2018 eatdirt <eatdirt> 0.9.8-2.mga7
+ Revision: 1251305
- Rebuild for new libnetcdf

* Sun Jun 24 2018 eatdirt <eatdirt> 0.9.8-1.mga7
+ Revision: 1239467
- Upgrade to version 0.9.8

* Sat Mar 17 2018 daviddavid <daviddavid> 0.9.7-7.mga7
+ Revision: 1210047
- rebuild for new proj 5.0.0

* Wed Dec 27 2017 wally <wally> 0.9.7-6.mga7
+ Revision: 1185642
- rebuild for new gsl

* Tue Nov 21 2017 tv <tv> 0.9.7-5.mga7
+ Revision: 1178359
- rebuild for new libproj

* Sun Oct 08 2017 eatdirt <eatdirt> 0.9.7-4.mga7
+ Revision: 1170190
- Fix build with new gcc

* Sat Jun 03 2017 akien <akien> 0.9.7-3.mga6
+ Revision: 1106096
- Rebuild for wxgtk 3.0.3.1

* Fri Feb 10 2017 eatdirt <eatdirt> 0.9.7-2.mga6
+ Revision: 1085252
- Rebuild for new plplot

* Wed Feb 01 2017 eatdirt <eatdirt> 0.9.7-1.mga6
+ Revision: 1084472
- Upgrade to bug fix release 0.9.7

* Tue Jan 31 2017 barjac <barjac> 0.9.6-4.mga6
+ Revision: 1084311
- Rebuild for eigen3

* Thu Jun 02 2016 daviddavid <daviddavid> 0.9.6-3.mga6
+ Revision: 1019798
- rebuild for wxgtk3.0 built with GTK2

* Fri May 20 2016 tv <tv> 0.9.6-2.mga6
+ Revision: 1017105
- rebuild for new libproj

* Wed Mar 09 2016 eatdirt <eatdirt> 0.9.6-1.mga6
+ Revision: 988523
- Upgrade to version 0.9.6

* Sun Jan 03 2016 luigiwalser <luigiwalser> 0.9.5-6.mga6
+ Revision: 919003
- rebuild for gsl

* Tue Dec 29 2015 tv <tv> 0.9.5-5.mga6
+ Revision: 916740
- rebuild for new libGraphicsMagick

* Fri Sep 25 2015 eatdirt <eatdirt> 0.9.5-4.mga6
+ Revision: 883409
- Rebuild for plplot-5.11.1

* Tue Jul 21 2015 daviddavid <daviddavid> 0.9.5-3.mga6
+ Revision: 855868
- rebuild with new hdf5

* Sun Feb 08 2015 eatdirt <eatdirt> 0.9.5-2.mga5
+ Revision: 814045
- Fix missing requires to plplot

* Thu Dec 04 2014 eatdirt <eatdirt> 0.9.5-1.mga5
+ Revision: 801561
- Fix missing BuildRequires
- Update to new version 0.9.5

* Wed Oct 15 2014 umeabot <umeabot> 0.9.4-6.mga5
+ Revision: 739197
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.4-5.mga5
+ Revision: 679821
- Mageia 5 Mass Rebuild

* Sat Aug 23 2014 fwang <fwang> 0.9.4-4.mga5
+ Revision: 666792
- rebuild for imagemagick

* Tue Feb 25 2014 eatdirt <eatdirt> 0.9.4-3.mga5
+ Revision: 596744
- Rebuild for new plplot

* Mon Oct 21 2013 umeabot <umeabot> 0.9.4-2.mga4
+ Revision: 538786
- Mageia 4 Mass Rebuild

* Wed Oct 02 2013 joequant <joequant> 0.9.4-1.mga4
+ Revision: 490390
- more fixes for plwid
- fix patch
- fix plplot api change
- upgrade to 0.9.4

* Thu Sep 19 2013 fwang <fwang> 0.9.3-6.mga4
+ Revision: 481482
- rebuild for new imagemagick

* Wed Aug 07 2013 fwang <fwang> 0.9.3-5.mga4
+ Revision: 464399
- rebuild for new imagemagick

* Tue Jul 16 2013 fwang <fwang> 0.9.3-4.mga4
+ Revision: 455008
- rebuild for new hdf5

* Tue May 28 2013 fwang <fwang> 0.9.3-3.mga4
+ Revision: 429159
- rebuild for new imagemagick

* Sat Jan 12 2013 umeabot <umeabot> 0.9.3-2.mga3
+ Revision: 352350
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 eatdirt <eatdirt> 0.9.3-1.mga3
+ Revision: 343110
- Upgrade to version 0.9.3

* Fri Dec 14 2012 fwang <fwang> 0.9.2-4.mga3
+ Revision: 330772
- rebuild for new imagemagick

* Fri Oct 12 2012 fwang <fwang> 0.9.2-3.mga3
+ Revision: 305128
- add more br

* Thu Jan 19 2012 fwang <fwang> 0.9.2-3.mga2
+ Revision: 198406
- build with wxgtku

* Sat Dec 10 2011 eatdirt <eatdirt> 0.9.2-2.mga2
+ Revision: 179886
- Rebuilt for fftw-3.3

* Wed Dec 07 2011 eatdirt <eatdirt> 0.9.2-1.mga2
+ Revision: 178252
- Upgrade to 0.9.2

* Mon Nov 07 2011 obgr_seneca <obgr_seneca> 0.9.1-3.mga2
+ Revision: 165148
- rebuild against new plplot

* Tue Sep 06 2011 eatdirt <eatdirt> 0.9.1-2.mga2
+ Revision: 139554
- imported package gnudl

